<?php
/**
 * Пример работы с классом, вывод в *.csv
 *
 * Скрипт получает параметр ИКС для запрашиваемых доменов и формирует .csv-файл.
 * Открыть можно с мощью Excel или OpenOffice Calc.
 * Разделитель значений — ; (точка с запятой)
 *
 * Дополнения
 *   2020-02-06:
 *     — После запроса данных скрипт будет работать «до упора».
 *     — Скрипт предлагает ссылку на csv-файл с данными последней проверки.
 */

// csv-файл с последней проверкой доменов
$file = 'lastiks.csv';
$fn = __DIR__ . DIRECTORY_SEPARATOR . $file;

if ( isset($_POST['domainlist']) ) {
    set_time_limit(0); // снять ограничение времени
    ignore_user_abort(TRUE); // если пользователь отсоединился — игнорировать
    
    include_once 'YandexIks.php';
    
    // FIX! ОС от Apple для перевода строк используют \r
    $_POST['domainlist'] = preg_replace("![\r\n]+!", "\n", $_POST['domainlist']);
    
    $domainlist = explode("\n", $_POST['domainlist']);
    $domainlist = array_map('trim', $domainlist);
    
    $csv = '';
    foreach ($domainlist as $domain) {
        if (!$domain) continue;
        $iks = YandexIks::getValueFromImage($domain);
        $csv .= $domain . ';' . (is_numeric($iks) ? $iks : '—') . "\r\n";
    }
    
    if ($csv) {
        $csv = "Domain;IKS\r\n" . $csv;
        file_put_contents($fn, $csv);
    } else {
        $err_str = 'Не удалось получить данные по доменам';
    }
}

header('Content-Type: text/html; charset=utf-8');
?><!doctype html>
<html>
  <head>
    <meta charset="utf-8">
    <title>Получение значения ИКС</title>
    <script type="text/javascript">
      window.addEventListener('load', function (){
        document.querySelector('input[type=submit]').onclick = function(){
            var
                txt = document.querySelector('textarea'),
                val = txt.value,
                domainlist = val.split("\n"),
                arr = [];
            
            for (let i in domainlist) {
                domainlist[i] = domainlist[i].replace(/[\s\uFEFF]+$/, '').replace(/^[\s\uFEFF]$/, '');
                if ('' != domainlist[i]) {
                    arr.push(domainlist[i].replace(/^([^:]+:\/\/)?([^\/]+).*$/, '$2'));
                }
            }
            
            txt.value = arr.join("\n");
            
            return arr.length > 0;
        };
      });
    </script>
  </head>
  
  <body>
    <h1>Получение значения Яндекс ИКС для группы доменов</h1>
<?php if (isset($err_str)) echo '<p style="color:#d00">' . $err_str . '</p>'; ?>
    <form action="" method="post">
      <p><textarea name="domainlist" cols="50" rows="20"></textarea><br>Введите домены, каждый с новой строки</p>
      <p><input type="submit" value="ok"></p>
    </form>
<?php
    if (file_exists($fn)) {
        echo '
    <p><a href="' . $file . '" target="_blank">Скачать данные последней проверки группы доменов</a> (' . filesize($fn) . ' байт)</p>
';
    }
?>
  </body>
</html>